/*
	This file is part of 

	'FractalView' - A Fractal Calculation Program for NeXTStep 3.x

	Author: 
		Peter Merz 
		Kaerntner Str. 9a 
		57223 Kreuztal - GERMANY

	Copyright (C) 1995 Peter Merz

	THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS 
	OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE 
	IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
	PARTICULAR PURPOSE.

	License to freely use and distribute this software is hereby granted,
 	by the author, subject to the condition that this copyright notice,
  	remains intact.  The author retains the exclusive right to publish,
	derivative works based on this work, including, but not limited to, 
  	revised versions of this work.

*/

#include "Complex.h"
extern "C" {
#include "Iterate.h"
}

unsigned IterateCos(double KRe, double KIm, double CRe, double CIm,int MaxTiefe) {

	Complex	k(KRe,KIm), c(CRe,CIm), z, z_old;
	register unsigned Count;

	
	z=k;
	if (c==0) { z=64; c=1; }
	Count=MaxTiefe;
	do {
		z_old=z;
  		z=z*z/cos(z)+1/c;
  		Count--;
 	}
	while(norm(z)<32 && norm(z-z_old)>0.00001 && Count);
	if (norm(z-z_old)<0.00001) return MaxTiefe; else 
	return MaxTiefe-Count;
 }



unsigned IterateSin(double KRe, double KIm, double CRe, double CIm,int MaxTiefe) {

	Complex	k(KRe,KIm), c(CRe,CIm), z;
	register unsigned Count;

	
	z=k;
	Count=MaxTiefe;
	do {
  		z=z*sin(z)+c;
  		Count--;
 	}
	while(norm(z)<16 && Count);
	return MaxTiefe-Count;
 }


unsigned IterateTan(double KRe, double KIm, double CRe, double CIm,int MaxTiefe) {

	Complex	k(KRe,KIm), c(CRe,CIm), z, z_old;
	register unsigned Count;

	
	z=k;
	Count=MaxTiefe;
	if (c==0) { z=64; c=1; }
	do {
		z_old=z;
  		z=z*tan(z)+1/c;
  		Count--;
 	}
	while(norm(z)<16 && norm(z-z_old)>0.00001 && Count);
	if (norm(z-z_old)<0.00001) return MaxTiefe; else 
	return MaxTiefe-Count;
 }

unsigned IterateSinh(double KRe, double KIm, double CRe, double CIm,int MaxTiefe) {

	Complex	k(KRe,KIm), c(CRe,CIm), z;
	register unsigned Count;

	
	z=k;
	Count=MaxTiefe;
	do {
  		z=z*sinh(z)+c;
  		Count--;
 	}
	while(norm(z)<16 && Count);
	return MaxTiefe-Count;
 }




unsigned IterateMagn2(double KRe, double KIm, double CRe, double CIm,int MaxTiefe) {

	Complex	k(KRe,KIm), c(CRe,CIm), z, z2, c1, c2;
	register unsigned Count;

	
	z=k;
	Count=MaxTiefe;
	do {
		z2=z*z; c1=c-1; c2=c-2;
  		z=((z2+3*c1)*z+c1*c2)/(3*z2+3*c2*z+c*c-3*c+3);
		z*=z;
  		Count--;
 	}
	while(norm(z)<1E6 && norm(z-1)>0.0001 && Count);
	if (norm(z-1)>0.0001) Count=0;
	return MaxTiefe-Count;
 }



